==> nextcloud-jitsi-v0.18.0.tar.gz: jitsi/l10n/ar.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "المؤتمرات",
    "Jitsi Integration" : "تكامل برنامج جيتسي",
    "Conferences" : "المؤتمرات",
    "Jitsi Integration (unofficial)" : "تكامل جيتسي (غير رسمي)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "يدمج هذا التطبيق برنامج المؤتمرات Jitsi conferences في نكست كلود.\n\nالميزات: \n- 🎥 إجراء مؤتمرات سهلة عبر الإنترنت في نكست كلود باستخدام برنامج Jitsi\n- 🔗 روابط غرف المؤتمرات قابلة للمشاركة\n-🔎 يُظهر قاعات المؤتمرات في البحث العالمي\n- ✅ اختبار النظام قبل الانضمام إلى مؤتمر \n\nيرجى قراءة [الوثائق] (https://github.com/nextcloud/jitsi).",
    "Loading …" : "جاري التحميل …",
    "Server URL (required)" : "عنوان URL للخادم (مطلوب)",
    "Help link (optional)" : "رابط المساعدة (اختياري)",
    "Display \"Join using the Jitsi app\"" : "عرض \"الانضمام باستخدام تطبيق Jitsi\"",
    "JWT Secret (optional)" : "سر JWT (اختياري)",
    "JWT App ID" : "معرف تطبيق JWT",
    "JWT Audience (optional)" : "جمهور JWT (اختياري)",
    "JWT Issuer (optional)" : "مُصدر JWT (اختياري)",
    "save" : "حفظ",
    "saved" : "تم الحفظ",
    "Saving …" : "جاري الحفظ…",
    "Please provide a Jitsi instance URL" : "يرجى تقديم عنوان URL لمثيل جيتسي",
    "The server URL must start with https://" : "يجب أن يبدأ عنوان URL للخادم بـ https:// ",
    "It is highly recommended to set up a dedicated Jitsi instance" : "يوصى بشدة بإعداد مثيل جيتسي مخصص",
    "Please provide the App ID" : "يرجى التزويد بمعرف التطبيق",
    "Failed to save settings" : "فشل حفظ الإعدادات",
    "Failed to load settings" : "إخفاق في تحميل الإعدادات",
    "Conference rooms" : "غرف المؤتمرات",
    "Conference" : "مؤتمر",
    "Conference left" : "مغادرة المؤتمر",
    "Problems detected" : "تم الكشف عن وجود مشاكل",
    "Your browser is non-optimal:" : "متصفحك غير مثالي:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "قد تكون جودة الصوت والفيديو رديئة. يوصى باستخدام  إصدار حديث من <b>متصفح Firefox / Chrome / Chromium</b>.",
    "Browser not supported" : "المتصفح غير مدعوم",
    "Show system check" : "عرض فحص النظام",
    "Your name:" : "اسمك:",
    "Click here to join" : "أنقر هنا للإنضمام",
    "Start muted" : "بدء صامت",
    "Start with camera off" : "ابدأ بإغلاق الكاميرا",
    "Join with desktop app" : "انضم مع تطبيق سطح المكتب",
    "Join with mobile app" : "انضم مع تطبيق الجوال",
    "App button not working?" : "زر التطبيق لا يعمل؟",
    "Download the desktop app here ↗" : "قم بتنزيل تطبيق سطح المكتب من هنا ↗",
    "The mobile app is available via the app store of your choice." : "تطبيق الهاتف متاح عبر متجر التطبيقات الذي تختاره.",
    "After successful installation try the button again." : "بعد التثبيت الناجح قم بتجربة الزر مرة أخرى.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "ما زلت لا تعمل؟ انسخ الرابط أدناه والصقه في حقل الإدخال في شاشة بدء تطبيق Jitsi.",
    "Link copied" : "تم نسخ الرابط",
    "Cannot copy, please copy the link manually" : "لا يمكن النسخ، يرجى نسخ الرابط يدويًا",
    "Copy to clipboard" : "نسخ الرابط",
    "Browser" : "المتصفح",
    "non-optimal" : "غير مثالي",
    "not supported" : "غير مدعوم",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "قد تكون جودة الصوت والفيديو رديئة. <br>يوصى باستخدام<b> إصدار حديث</b> من متصفح Firefox / Chrome / Chromium.",
    "Help" : "مساعدة",
    "Camera" : "الكاميرا",
    "Name of the new room" : "اسم الغرفة الجديدة",
    "No conference rooms yet" : "لا توجد غرف اجتماعات حتى الآن",
    "Create the first room:" : "إنشاء الغرفة الأولى:",
    "Microphone" : "الميكروفون",
    "Join" : "إن",
    "Delete room" : "حذف الغرفة",
    "Room not found" : "الغرفة غير موجودة",
    "Please check the link/URL and ask your host" : "يرجى التحقق من الرابط /عنوان URL واسأل مضيفك",
    "Audio output" : "مخرج الصوت",
    "Play test sound" : "تشغيل اختبار الصوت",
    "System check" : "فحص النظام",
    "Got issues?" : "هل لديك مشاكل؟",
    "Known problems / what you can try" : "المشاكل المعروفة/ ما يمكن أن يواجهك",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• الموافقة علي أذونات الوصول إلى الميكروفون / الكاميرا في الجزء العلوي من الشاشة",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• تحقق من أذونات الوصول إلى الميكروفون / الكاميرا عن طريق النقر فوق الرمز الموجود بجوار شريط العناوين. ثم إعادة تحميل الصفحة.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• إذا كان لديك DroidCam: اتصل بكاميرا الهاتف المحمول، ثم أعد تحميل الصفحة",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• حاول الانضمام باستخدام تطبيق جيتسي (اتبع التعليمات في أسفل الصفحة)",
    "No camera/microphone access" : "لا يوجد وصول إلى الكاميرا / الميكروفون",
    "Review your browser camera and microphone access settings" : "راجع إعدادات الوصول إلى الكاميرا والميكروفون في متصفحك",
    "Click here for {browser} instructions" : "انقر هنا للحصول على إرشادات بشأن {browser}",
    "Does not work?" : "لا يعمل؟",
    "Click here for troubleshooting help" : "انقر هنا للحصول على مساعدة بشأن استكشاف الأخطاء وإصلاحها",
    "Conferences app not yet configured" : "لم يتم تكوين تطبيق المؤتمرات بعد",
    "Please contact your administrator to set up the conferences app." : "يرجى الاتصال بالمسؤول لإعداد تطبيق المؤتمرات.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "متصفحك (%1$s) قديم و<br>لم يعد مدعومًا",
    "It is recommended to use the latest version of one of the following browsers:" : "يوصى باستخدام أحدث إصدار من أحد المتصفحات التالية:"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-jitsi-v0.19.0.tar.gz: jitsi/l10n/ar.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "المؤتمرات",
    "Jitsi Integration" : "تكامل برنامج جيتسي",
    "Conferences" : "المؤتمرات",
    "Jitsi Integration (unofficial)" : "تكامل جيتسي (غير رسمي)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "يدمج هذا التطبيق برنامج المؤتمرات Jitsi conferences في نكست كلود.\n\nالميزات: \n- 🎥 إجراء مؤتمرات سهلة عبر الإنترنت في نكست كلود باستخدام برنامج Jitsi\n- 🔗 روابط غرف المؤتمرات قابلة للمشاركة\n-🔎 يُظهر قاعات المؤتمرات في البحث العالمي\n- ✅ اختبار النظام قبل الانضمام إلى مؤتمر \n\nيرجى قراءة [الوثائق] (https://github.com/nextcloud/jitsi).",
    "Loading …" : "التحميل جارٍ ...",
    "Server URL (required)" : "عنوان URL للخادم (مطلوب)",
    "Help link (optional)" : "رابط المساعدة (اختياري)",
    "Display \"Join using the Jitsi app\"" : "عرض \"الانضمام باستخدام تطبيق Jitsi\"",
    "JWT Secret (optional)" : "سر JWT (اختياري)",
    "JWT App ID" : "معرف تطبيق JWT",
    "JWT Audience (optional)" : "جمهور JWT (اختياري)",
    "JWT Issuer (optional)" : "مُصدر JWT (اختياري)",
    "save" : "حفظ",
    "saved" : "تم الحفظ",
    "Saving …" : "جاري الحفظ…",
    "Please provide a Jitsi instance URL" : "يرجى تقديم عنوان URL لمثيل جيتسي",
    "The server URL must start with https://" : "يجب أن يبدأ عنوان URL للخادم بـ https:// ",
    "It is highly recommended to set up a dedicated Jitsi instance" : "يوصى بشدة بإعداد مثيل جيتسي مخصص",
    "Please provide the App ID" : "يرجى التزويد بمعرف التطبيق",
    "Failed to save settings" : "فشل حفظ الإعدادات",
    "Failed to load settings" : "فشل في تحميل الإعدادات",
    "Conference rooms" : "غرف المؤتمرات",
    "Conference" : "مؤتمر",
    "Conference left" : "مغادرة المؤتمر",
    "Problems detected" : "تم الكشف عن وجود مشاكل",
    "Your browser is non-optimal:" : "متصفحك غير مثالي:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "قد تكون جودة الصوت والفيديو رديئة. يوصى باستخدام  إصدار حديث من <b>متصفح Firefox / Chrome / Chromium</b>.",
    "Browser not supported" : "المتصفح غير مدعوم",
    "Show system check" : "عرض فحص النظام",
    "Your name:" : "اسمك:",
    "Click here to join" : "أنقر هنا للإنضمام",
    "Start muted" : "بدء صامت",
    "Start with camera off" : "ابدأ بإغلاق الكاميرا",
    "Join with desktop app" : "انضم مع تطبيق سطح المكتب",
    "Join with mobile app" : "انضم مع تطبيق الجوال",
    "App button not working?" : "زر التطبيق لا يعمل؟",
    "Download the desktop app here ↗" : "قم بتنزيل تطبيق سطح المكتب من هنا ↗",
    "The mobile app is available via the app store of your choice." : "تطبيق الهاتف متاح عبر متجر التطبيقات الذي تختاره.",
    "After successful installation try the button again." : "بعد التثبيت الناجح قم بتجربة الزر مرة أخرى.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "ما زلت لا تعمل؟ انسخ الرابط أدناه والصقه في حقل الإدخال في شاشة بدء تطبيق Jitsi.",
    "Link copied" : "تم نسخ الرابط",
    "Cannot copy, please copy the link manually" : "لا يمكن النسخ، يرجى نسخ الرابط يدويًا",
    "Copy to clipboard" : "نسخ الرابط",
    "Browser" : "المتصفح",
    "non-optimal" : "غير مثالي",
    "not supported" : "غير مدعوم",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "قد تكون جودة الصوت والفيديو رديئة. <br>يوصى باستخدام<b> إصدار حديث</b> من متصفح Firefox / Chrome / Chromium.",
    "Help" : "مساعدة",
    "Camera" : "الكاميرا",
    "Name of the new room" : "اسم الغرفة الجديدة",
    "No conference rooms yet" : "لا توجد غرف اجتماعات حتى الآن",
    "Create the first room:" : "إنشاء الغرفة الأولى:",
    "Microphone" : "الميكروفون",
    "Join" : "إن",
    "Delete room" : "حذف الغرفة",
    "Room not found" : "الغرفة غير موجودة",
    "Please check the link/URL and ask your host" : "يرجى التحقق من الرابط /عنوان URL واسأل مضيفك",
    "Audio output" : "مخرج الصوت",
    "Play test sound" : "تشغيل اختبار الصوت",
    "System check" : "فحص النظام",
    "Got issues?" : "هل لديك مشاكل؟",
    "Known problems / what you can try" : "المشاكل المعروفة/ ما يمكن أن يواجهك",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• الموافقة علي أذونات الوصول إلى الميكروفون / الكاميرا في الجزء العلوي من الشاشة",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• تحقق من أذونات الوصول إلى الميكروفون / الكاميرا عن طريق النقر فوق الرمز الموجود بجوار شريط العناوين. ثم إعادة تحميل الصفحة.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• إذا كان لديك DroidCam: اتصل بكاميرا الهاتف المحمول، ثم أعد تحميل الصفحة",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• حاول الانضمام باستخدام تطبيق جيتسي (اتبع التعليمات في أسفل الصفحة)",
    "No camera/microphone access" : "لا يوجد وصول إلى الكاميرا / الميكروفون",
    "Review your browser camera and microphone access settings" : "راجع إعدادات الوصول إلى الكاميرا والميكروفون في متصفحك",
    "Click here for {browser} instructions" : "انقر هنا للحصول على إرشادات بشأن {browser}",
    "Does not work?" : "لا يعمل؟",
    "Click here for troubleshooting help" : "انقر هنا للحصول على مساعدة بشأن استكشاف الأخطاء وإصلاحها",
    "Conferences app not yet configured" : "لم يتم تكوين تطبيق المؤتمرات بعد",
    "Please contact your administrator to set up the conferences app." : "يرجى الاتصال بالمسؤول لإعداد تطبيق المؤتمرات.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "متصفحك (%1$s) قديم و<br>لم يعد مدعومًا",
    "It is recommended to use the latest version of one of the following browsers:" : "يوصى باستخدام أحدث إصدار من أحد المتصفحات التالية:"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
